@@ -3,7 +3,7 @@ BEGIN {
   $App::Pocoirc::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::Pocoirc::VERSION = '0.11';
+  $App::Pocoirc::VERSION = '0.12';
 }
 
 use strict;
@@ -20,24 +20,6 @@ sub new {
 sub run {
     my ($self) = @_;
 
-    if (my $log = delete $self->{cfg}{log_file}) {
-        open my $fh, '>>', $log or die "Can't open $log: $!\n";
-        close $fh;
-        $self->{log_file} = $log;
-    }
-
-    if (!$self->{no_color}) {
-        require Term::ANSIColor;
-        Term::ANSIColor->import();
-    }
-
-    if ($self->{daemonize} && !$self->{check_cfg}) {
-        require Proc::Daemon;
-        eval { Proc::Daemon::Init->() };
-        chomp $@;
-        die "Can't daemonize: $@\n" if $@;
-    }
-
     POE::Session->create(
         object_states => [
             $self => [qw(
@@ -74,15 +56,11 @@ sub run {
 sub _start {
     my ($kernel, $session, $self) = @_[KERNEL, SESSION, OBJECT];
 
-    $kernel->sig(DIE => '_exception');
-
-    if (defined $self->{cfg}{lib} && @{ $self->{cfg}{lib} }) {
-        my $lib = delete $self->{cfg}{lib};
-        unshift @INC, @$lib;
-    }
+    # misc things
+    $self->_global_setup();
 
+    # compilation and config validation
     $self->_require_plugin($_) for @{ $self->{cfg}{global_plugins} || [] };
-
     for my $opts (@{ $self->{cfg}{networks} }) {
         $self->_require_plugin($_) for @{ $opts->{local_plugins} || [] };
 
@@ -103,16 +81,26 @@ sub _start {
         die "Can't load class $opts->{class}: $@\n" if $@;
     }
 
-    # this can not be done earlier due to a bug in Perl 5.12 which causes
-    # the compilation of Net::DNS (used by POE::Component::IRC) to clear
-    # the signal handler
-    $kernel->sig(INT => '_exit');
-
     if ($self->{check_cfg}) {
         print "Config file is valid all modules could be compiled.\n";
         return;
     }
 
+    if ($self->{daemonize}) {
+        require Proc::Daemon;
+        eval { Proc::Daemon::Init->() };
+        chomp $@;
+        die "Can't daemonize: $@\n" if $@;
+    }
+
+    # all exceptions will now be colored & timestamped status messages
+    $kernel->sig(DIE => '_exception');
+
+    # this can not be done earlier due to a bug in Perl 5.12 which causes
+    # the compilation of Net::DNS (used by POE::Component::IRC) to clear
+    # the signal handler
+    $kernel->sig(INT => '_exit');
+
     $self->_status("Started");
 
     # construct global plugins
@@ -163,6 +151,29 @@ sub _start {
     return;
 }
 
+# a few things to take care of at start up
+sub _global_setup {
+    my ($self) = @_;
+
+    if (my $log = delete $self->{cfg}{log_file}) {
+        open my $fh, '>>', $log or die "Can't open $log: $!\n";
+        close $fh;
+        $self->{log_file} = $log;
+    }
+
+    if (!$self->{no_color}) {
+        require Term::ANSIColor;
+        Term::ANSIColor->import();
+    }
+
+    if (defined $self->{cfg}{lib} && @{ $self->{cfg}{lib} }) {
+        my $lib = delete $self->{cfg}{lib};
+        unshift @INC, @$lib;
+    }
+
+    return;
+}
+
 sub irc_connected {
     my ($self, $address) = @_[OBJECT, ARG0];
     my $irc = $_[SENDER]->get_heap();
